##  Tech Category Management
When synchronizing data between ServiceNow and SAP LeanIX, where is the tech category fact sheet data typically mastered in line with best practices? We're transitioning to a service-centric IT delivery model and wonder if our ITSM should provide service groupings to populate tech categories.
If you're using the TBM Taxonomy, we recommend using tech category data from the reference catalog. For more information, see [Tech Categories in the Reference Catalog](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Tech categories in the reference catalog enable you to adopt the Technology Business Management \(TBM\) Taxonomy.").
YesNo
Send
